@@ -1376,15 +1376,25 @@ PatchFilterTypeDef = TypedDict(
     "PatchFilterTypeDef",
     {
         "Key": Literal[
+            "ARCH",
+            "ADVISORY_ID",
+            "BUGZILLA_ID",
             "PATCH_SET",
             "PRODUCT",
             "PRODUCT_FAMILY",
             "CLASSIFICATION",
+            "CVE_ID",
+            "EPOCH",
             "MSRC_SEVERITY",
+            "NAME",
             "PATCH_ID",
             "SECTION",
             "PRIORITY",
+            "REPOSITORY",
+            "RELEASE",
             "SEVERITY",
+            "SECURITY",
+            "VERSION",
         ],
         "Values": List[str],
     },
@@ -1453,6 +1463,16 @@ PatchTypeDef = TypedDict(
         "KbNumber": str,
         "MsrcNumber": str,
         "Language": str,
+        "AdvisoryIds": List[str],
+        "BugzillaIds": List[str],
+        "CVEIds": List[str],
+        "Name": str,
+        "Epoch": int,
+        "Version": str,
+        "Release": str,
+        "Arch": str,
+        "Severity": str,
+        "Repository": str,
     },
     total=False,
 )
